@@ -1,6 +1,8 @@
+"""
+"""
 from importlib import metadata
 
 __version__ = metadata.version(__package__)
-__authors__ = metadata.metadata(__package__)["Author"]
+__authors__ = metadata.metadata(__package__)["Author-email"]
 
 del metadata  # optional, avoids polluting the results of dir(__package__)
